Sprox
==============

.. image:: https://travis-ci.org/TurboGears/sprox.png
    :target: https://travis-ci.org/TurboGears/sprox 

.. image:: https://coveralls.io/repos/TurboGears/sprox/badge.png
    :target: https://coveralls.io/r/TurboGears/sprox

.. image:: https://pypip.in/v/sprox/badge.png
   :target: https://pypi.python.org/pypi/sprox

.. image:: https://pypip.in/d/sprox/badge.png
   :target: https://pypi.python.org/pypi/sprox

Form Generation from database schema for ToscaWidgets with support for various database backends

License
-----------

Sprox is licensed under an MIT-style license (see LICENSE.txt).
Other incorporated projects may be licensed under different licenses.
All licenses allow for non-commercial and commercial use.


